==> paraview-0.9.0.zip: paraview-0.9.0/Qt/Widgets/Testing/Cxx/pqTextEditTest.h <==
/*=========================================================================

   Program: ParaView
   Module:    pqTextEditTest.h

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/

#ifndef pqTextEditTest_h
#define pqTextEditTest_h

#include <QObject>

class QSignalSpy;
class pqTextEdit;

class pqTextEditTester : public QObject
{
  Q_OBJECT

public:
  enum SpyType
  {
    TextChanged = 0,
    EditingFinished,
    TextChangedAndEditingFinished,
  };

private Q_SLOTS:
  void init();
  void cleanup();

  void testSets();
  void testSets_data();
  void testTypeText();
  void testTypeText_data();
  void testFocus();
  void testFocus_data();
  void testReTypeText();
  void testReTypeText_data();

private: // NOLINT(readability-redundant-access-specifiers)
  pqTextEdit* TextEdit;
  QSignalSpy* TextChangedSpy;
  QSignalSpy* EditingFinishedSpy;
  QSignalSpy* TextChangedAndEditingFinishedSpy;

  QSignalSpy* spy(int spy);
};

#endif

==> paraview-v4.3.0.zip: paraview-v4.3.0/Qt/Widgets/Testing/Cxx/pqTextEditTest.h <==
/*=========================================================================

   Program: ParaView
   Module:    pqTextEditTest.h

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2. 

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/

#ifndef __pqTextEditTest_h
#define __pqTextEditTest_h

#include <QObject>

class QSignalSpy;
class pqTextEdit;

class pqTextEditTester: public QObject
{
  Q_OBJECT

public:
  enum SpyType
    {
    TextChanged = 0,
    EditingFinished,
    TextChangedAndEditingFinished,
    };

private slots:
  void init();
  void cleanup();

  void testSets();
  void testSets_data();
  void testTypeText();
  void testTypeText_data();
  void testFocus();
  void testFocus_data();
  void testReTypeText();
  void testReTypeText_data();

private:
  pqTextEdit* TextEdit;
  QSignalSpy* TextChangedSpy;
  QSignalSpy* EditingFinishedSpy;
  QSignalSpy* TextChangedAndEditingFinishedSpy;

  QSignalSpy* spy(int spy);
};

#endif
